@@ -1,5 +1,6 @@
 use super::component::LoggerComponent;
 use std::io::Error;
+use crate::core::logger::message::Message;
 
 pub struct ConsoleComponent {}
 
@@ -10,8 +11,8 @@ impl ConsoleComponent {
 }
 
 impl LoggerComponent for ConsoleComponent {
-    fn log(&mut self, msg: &str) -> Result<(), Error> {
-        println!("{}", msg);
+    fn log(&mut self, msg: &Message) -> Result<(), Error> {
+        println!("{}", msg.to_string());
         Ok(())
     }
 }
